@@ -1,4 +1,4 @@
 textindsup <- function(resmca,supdata,axes=c(1,2),col='darkred') {
-    coord <- indsup(resmca,supdata)$coord
+    coord <- supind(resmca,supdata)$coord
     text(coord[,axes],rownames(coord),col=col)
-    }
\ No newline at end of file
+    }
